SystemOrganization addCategory: #SourceCity!

Object subclass: #CityImporter
	instanceVariableNames: 'classes methods packages city districts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityImporter commentStamp: '<historical>' prior: 0!
I'm responsible for populating a city from a model (usually a ring model)!

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:44'!
basicDistrict: aPackageName

	 | d |
	d := District new model: (self packageNamed: aPackageName).
	city add: d.
	^d
	
	! !

!CityImporter methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:39'!
city

	^city! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 14:38'!
cityNamed: aName withPackageNames: aCol

	city := City new name: aName.
	aCol do: [:each |
				self importPackageAsDistrict: each ]! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:44'!
ensureDistrict: aPackageName

	^ districts 
			at: aPackageName 
			ifAbsentPut: [ self basicDistrict: aPackageName].
			
						! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 10:04'!
getAllClasses
	
	^classes! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 11:05'!
getAllClassesSize
	
	^classes size! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 10:45'!
getAllPackages
	
	^packages! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 11:05'!
getAllPackagesSize
	
	^packages size! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 11:00'!
getMethods: aClass
	
	^aClass methods! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 13:18'!
getMethodsLine: aMethod
	
	^aMethod size.! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 13:18'!
getMethodsSize: aClass
	
	^aClass methods size.! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:43'!
importPackageAsDistrict: aPackageName

	| ctPack |
	ctPack := self ensureDistrict: aPackageName.
	! !

!CityImporter methodsFor: 'initialize-release' stamp: 'DouailleErwan 4/2/2012 14:34'!
initialize

	super initialize.
	districts := Dictionary new.! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 14:21'!
initialize2
	packages := RPackageOrganizer default packages.
	
	classes := OrderedCollection new.
	packages do: [ :each |
		(each classes) do:[:aclass | 
			classes add: aclass.
			].
	].
	classes := classes asArray.
	
	
	! !

!CityImporter methodsFor: 'utils' stamp: 'DouailleErwan 4/2/2012 14:28'!
packageNamed: aString

	^ RPackageOrganizer default packageNamed: aString! !

!CityImporter methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 13:23'!
refresh
	
	packages := RPackageOrganizer default packages.
	
	classes := OrderedCollection new.
	packages do: [ :each |
		(each classes) do:[:aclass | 
			classes add: aclass.
			].
	].
	classes := classes asArray.
	
	! !

Object subclass: #CityObject
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityObject commentStamp: '<historical>' prior: 0!
I'm an abstract class root of the city elements!

CityObject subclass: #Building
	instanceVariableNames: 'size aColor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

CityObject subclass: #City
	instanceVariableNames: 'districts name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!City commentStamp: '<historical>' prior: 0!
A City represents the largest model element. It contains a list of districts.!

!City methodsFor: 'adding' stamp: 'DouailleErwan 4/2/2012 14:13'!
add: aDistrict

	districts add: aDistrict.
	^ aDistrict! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:36'!
districts

	^ districts! !

!City methodsFor: 'testing' stamp: 'DouailleErwan 4/2/2012 14:48'!
hasDistrictNamed: aString
	
	^ districts anySatisfy: [:each | each model name = aString]! !

!City methodsFor: 'initialize-release' stamp: 'DouailleErwan 4/2/2012 14:12'!
initialize

	super initialize.
	districts := OrderedCollection new! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name
	^ name! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name1
	^ name! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name: anObject
	name := anObject! !

!CityObject methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:10'!
model 
	"Returns the model associated with the receiver, it can be a class, package...."
	
	^model! !

!CityObject methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:10'!
model: aModel
	"Set the model associated with the receiver, it can be a class, package...."
	
	model := aModel! !

CityObject subclass: #District
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!District commentStamp: '<historical>' prior: 0!
A District is a secondary city abstractions!

!District methodsFor: 'printing' stamp: 'DouailleErwan 4/2/2012 14:46'!
printOn: aStream

	super printOn: aStream.
	model ifNotNil: [ aStream 
					nextPutAll: ' ('; 
					nextPutAll: model name ; 
					nextPutAll: ')']! !

Object subclass: #ToolCity
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!ToolCity methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 13:29'!
initialize! !

!ToolCity methodsFor: 'as yet unclassified' stamp: 'DouailleErwan 4/2/2012 13:32'!
initializeFrom: aSystemInformation

	! !

TestCase subclass: #CityImporterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityImporterTest methodsFor: 'tests' stamp: 'DouailleErwan 4/2/2012 15:40'!
testImportPackageAsDistrict
	"self debug: #testImportPackageAsDistrict"
	
	| cimport |
	cimport := CityImporter new.
	cimport cityNamed: 'CodCT' withPackageNames: #('AST-Core' ).
	self assert: cimport city districts size =1.
	self assert: (cimport city hasDistrictNamed: #'AST-Core').
	! !

!CityImporterTest methodsFor: 'tests' stamp: 'DouailleErwan 4/2/2012 15:42'!
testImportPackageAsDistrictNoDuplicate
	"self debug: #testImportPackageAsDistrictNoDuplicate"
	
	| cimport |
	cimport := CityImporter new.
	cimport cityNamed: 'CodCT' withPackageNames: #('AST-Core' 'SourceCity' 'AST-Core').
	self assert: cimport city districts size = 2.
	self assert: (cimport city hasDistrictNamed: #'AST-Core').
	! !

TestCase subclass: #CityTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityTest methodsFor: 'testing' stamp: 'DouailleErwan 4/2/2012 14:05'!
testModel
	"self debug: #testModel"
	
	self assert: true! !
